Date: Mon, 17 Jul 2017 17:48:02 -0000
localoptions -> custom_options
sysoptions   -> constant_options
---
 .gitignore                         | 2 +-
 sysoptions.h => constant_options.h | 0
 default_options.h.in               | 5 +++--
 libtomcrypt/Makefile.in            | 2 +-
 options.h                          | 9 ++++-----
 options.mk                         | 8 ++++----
 release.sh                         | 2 +-
 7 files changed, 14 insertions(+), 14 deletions(-)
 rename sysoptions.h => constant_options.h (100%)

diff --git a/.gitignore b/.gitignore
index 58cd889..7eeb2e2 100644
--- a/.gitignore
+++ b/.gitignore
@@ -19,6 +19,6 @@
 Makefile
 config.h
 config.h.in
-/localoptions.h
+/custom_options.h
 configure
 /prerequisites/
diff --git a/sysoptions.h b/constant_options.h
similarity index 100%
rename from sysoptions.h
rename to constant_options.h
diff --git a/default_options.h.in b/default_options.h.in
index bc16f90..2ba3d87 100644
--- a/default_options.h.in
+++ b/default_options.h.in
@@ -3,8 +3,9 @@
 
 // This file documents compile-time options, and provides default values.
 //
-// Local customisation should be added to localoptions.h; options defined
-// there will override the defaults.
+// Local customisation should be added to `custom_options.h' (located in the
+// directory in which `make' is run); options defined there will override
+// the defaults.
 //
 // Many options are toggles that can be enabled or disabled.
 //
diff --git a/libtomcrypt/Makefile.in b/libtomcrypt/Makefile.in
index eb06395..550a832 100644
--- a/libtomcrypt/Makefile.in
+++ b/libtomcrypt/Makefile.in
@@ -269,7 +269,7 @@ include $(srcdir)/../options.mk
 
 src/misc/zeromem.o: ../dbhelpers.h
 src/math/ltm_desc.o: ../libtommath/tommath.h ../libtommath/tommath_class.h 
../libtommath/tommath_superclass.h
-$(OBJECTS): ../config.h ../options.h $(options_headers) ../sysoptions.h
+$(OBJECTS): ../config.h ../options.h $(options_headers) ../constant_options.h
 $(OBJECTS): $(HEADERS)
 
 $(default_options_h): $(default_options_h).in
diff --git a/options.mk b/options.mk
index 5ae7d79..7d5bf5c 100644
--- a/options.mk
+++ b/options.mk
@@ -1,9 +1,9 @@
 default_options_h_name:=default_options.h
 
-localoptions_h:=$(options_headers_dir)/localoptions.h
+custom_options_h:=$(options_headers_dir)/custom_options.h
 default_options_h:=$(options_headers_dir)/$(default_options_h_name)
 
-options_headers:=$(localoptions_h) $(default_options_h)
+options_headers:=$(custom_options_h) $(default_options_h)
 
-$(localoptions_h):
-       touch $(localoptions_h)
+$(custom_options_h):
+       touch $(custom_options_h)
diff --git a/release.sh b/release.sh
index d2abe14..ffb5619 100755
--- a/release.sh
+++ b/release.sh
@@ -1,5 +1,5 @@
 #!/bin/sh
-VERSION=$(echo '#include "sysoptions.h"\necho DROPBEAR_VERSION' | cpp - | sh)
+VERSION=$(echo '#include "constant_options.h"\necho DROPBEAR_VERSION' | cpp - 
| sh)
 echo Releasing version "$VERSION" ...
 if ! head -n1 CHANGES | grep -q $VERSION ; then
        echo "CHANGES needs updating"
diff --git a/options.h b/options.h
index 7465d91..650bdf0 100644
--- a/options.h
+++ b/options.h
@@ -4,15 +4,14 @@
 /* 
             > > > Don't edit this file any more! < < <
             
-Local compile-time configuration should be defined in localoptions.h
+Local compile-time configuration should be defined in custom_options.h
 See default_options.h.in for a description of the available options.
 */
 
-#include "localoptions.h"
+#include "custom_options.h"
 #include "default_options.h"
 
 /* Some other defines that mostly should be left alone are defined
  * in sysoptions.h */
 #include "sysoptions.h"
 
 #endif /* DROPBEAR_OPTIONS_H */
@@ -4,15 +4,14 @@
 #include "default_options.h"
 
-/* Some other defines that mostly should be left alone are defined
- * in sysoptions.h */
-#include "sysoptions.h"
+/* This provides some other options that mostly should be left alone. */
+#include "constant_options.h"
 
 #endif /* DROPBEAR_OPTIONS_H */
-- 
2.10.0

Reply via email to